==> jc-1.4.0.tar.gz: soot/toolkits/scalar/SimpleLiveLocals.h <==
// public class soot.toolkits.scalar.SimpleLiveLocals

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 6e5d4dfc8590d5ad soot_toolkits_scalar_SimpleLiveLocals

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_toolkits_scalar_SimpleLiveLocals_H_
#define _JC_soot_toolkits_scalar_SimpleLiveLocals_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_util_List$object;
struct _jc_java_util_Map$object;
struct _jc_soot_Unit$object;
struct _jc_soot_toolkits_graph_UnitGraph$object;

// Typedefs
typedef struct _jc_soot_toolkits_scalar_SimpleLiveLocals$sub_refs	_jc_soot_toolkits_scalar_SimpleLiveLocals$sub_refs;
typedef struct _jc_soot_toolkits_scalar_SimpleLiveLocals$sub_nonrefs	_jc_soot_toolkits_scalar_SimpleLiveLocals$sub_nonrefs;
typedef struct _jc_soot_toolkits_scalar_SimpleLiveLocals$refs	_jc_soot_toolkits_scalar_SimpleLiveLocals$refs;
typedef struct _jc_soot_toolkits_scalar_SimpleLiveLocals$nonrefs	_jc_soot_toolkits_scalar_SimpleLiveLocals$nonrefs;
typedef struct _jc_soot_toolkits_scalar_SimpleLiveLocals$object	_jc_soot_toolkits_scalar_SimpleLiveLocals$object;

typedef const struct _jc_soot_toolkits_scalar_SimpleLiveLocals$vmethods	_jc_soot_toolkits_scalar_SimpleLiveLocals$vmethods;
typedef const struct _jc_soot_toolkits_scalar_SimpleLiveLocals$vtable	_jc_soot_toolkits_scalar_SimpleLiveLocals$vtable;
typedef const struct _jc_soot_toolkits_scalar_SimpleLiveLocals$vtype	_jc_soot_toolkits_scalar_SimpleLiveLocals$vtype;

// Constructors
extern void _jc_soot_toolkits_scalar_SimpleLiveLocals$method$_init$4a1d314cee6c2507(_jc_env *, struct _jc_soot_toolkits_scalar_SimpleLiveLocals$object *, struct _jc_soot_toolkits_graph_UnitGraph$object *);

// Virtual methods
extern struct _jc_object *_jc_soot_toolkits_scalar_SimpleLiveLocals$method$getLiveLocalsAfter$18404ef042e9c3a3(_jc_env *, struct _jc_soot_toolkits_scalar_SimpleLiveLocals$object *, struct _jc_object *);
extern struct _jc_object *_jc_soot_toolkits_scalar_SimpleLiveLocals$method$getLiveLocalsBefore$9ac8223d771605d4(_jc_env *, struct _jc_soot_toolkits_scalar_SimpleLiveLocals$object *, struct _jc_object *);

// Virtual method descriptors
extern _jc_method _jc_soot_toolkits_scalar_SimpleLiveLocals$method_info$getLiveLocalsAfter$18404ef042e9c3a3;
extern _jc_method _jc_soot_toolkits_scalar_SimpleLiveLocals$method_info$getLiveLocalsBefore$9ac8223d771605d4;

// Virtual methods structure
struct _jc_soot_toolkits_scalar_SimpleLiveLocals$vmethods {
	struct _jc_object	*(*getLiveLocalsAfter$18404ef042e9c3a3)(_jc_env *, struct _jc_soot_toolkits_scalar_SimpleLiveLocals$object *, struct _jc_object *);
	struct _jc_object	*(*getLiveLocalsBefore$9ac8223d771605d4)(_jc_env *, struct _jc_soot_toolkits_scalar_SimpleLiveLocals$object *, struct _jc_object *);
};

// Vtable
struct _jc_soot_toolkits_scalar_SimpleLiveLocals$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_toolkits_scalar_SimpleLiveLocals$vmethods	soot_toolkits_scalar_SimpleLiveLocals;
};

// Vtype
struct _jc_soot_toolkits_scalar_SimpleLiveLocals$vtype {
	_jc_type			type;
	_jc_soot_toolkits_scalar_SimpleLiveLocals$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_toolkits_scalar_SimpleLiveLocals$sub_refs {
	struct _jc_object	*unitToLocalsAfter;
	struct _jc_object	*unitToLocalsBefore;
};

// Reference instance fields (object)
struct _jc_soot_toolkits_scalar_SimpleLiveLocals$refs {
    _jc_soot_toolkits_scalar_SimpleLiveLocals$sub_refs	soot_toolkits_scalar_SimpleLiveLocals;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_toolkits_scalar_SimpleLiveLocals$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_toolkits_scalar_SimpleLiveLocals$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_toolkits_scalar_SimpleLiveLocals$sub_nonrefs	soot_toolkits_scalar_SimpleLiveLocals;
};

// Object instance structure
struct _jc_soot_toolkits_scalar_SimpleLiveLocals$object {
	_jc_soot_toolkits_scalar_SimpleLiveLocals$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_toolkits_scalar_SimpleLiveLocals$vtype	*vtype;
	_jc_soot_toolkits_scalar_SimpleLiveLocals$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_toolkits_scalar_SimpleLiveLocals$vtype _jc_soot_toolkits_scalar_SimpleLiveLocals$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_toolkits_scalar_SimpleLiveLocals, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_toolkits_scalar_SimpleLiveLocals$class_object;

#endif	/* _JC_soot_toolkits_scalar_SimpleLiveLocals_H_ */

==> jc-1.4.6.tar.gz: soot/toolkits/scalar/SimpleLiveLocals.h <==
// public class soot.toolkits.scalar.SimpleLiveLocals

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 6e5d4dfc8590d5ad soot_toolkits_scalar_SimpleLiveLocals

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_toolkits_scalar_SimpleLiveLocals_H_
#define _JC_soot_toolkits_scalar_SimpleLiveLocals_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_util_List$object;
struct _jc_java_util_Map$object;
struct _jc_soot_Unit$object;
struct _jc_soot_toolkits_graph_UnitGraph$object;

// Typedefs
typedef struct _jc_soot_toolkits_scalar_SimpleLiveLocals$sub_refs	_jc_soot_toolkits_scalar_SimpleLiveLocals$sub_refs;
typedef struct _jc_soot_toolkits_scalar_SimpleLiveLocals$sub_nonrefs	_jc_soot_toolkits_scalar_SimpleLiveLocals$sub_nonrefs;
typedef struct _jc_soot_toolkits_scalar_SimpleLiveLocals$refs	_jc_soot_toolkits_scalar_SimpleLiveLocals$refs;
typedef struct _jc_soot_toolkits_scalar_SimpleLiveLocals$nonrefs	_jc_soot_toolkits_scalar_SimpleLiveLocals$nonrefs;
typedef struct _jc_soot_toolkits_scalar_SimpleLiveLocals$object	_jc_soot_toolkits_scalar_SimpleLiveLocals$object;

typedef const struct _jc_soot_toolkits_scalar_SimpleLiveLocals$vmethods	_jc_soot_toolkits_scalar_SimpleLiveLocals$vmethods;
typedef const struct _jc_soot_toolkits_scalar_SimpleLiveLocals$vtable	_jc_soot_toolkits_scalar_SimpleLiveLocals$vtable;
typedef const struct _jc_soot_toolkits_scalar_SimpleLiveLocals$vtype	_jc_soot_toolkits_scalar_SimpleLiveLocals$vtype;

// Constructors
extern void _jc_soot_toolkits_scalar_SimpleLiveLocals$method$_init$4a1d314cee6c2507(_jc_env *, struct _jc_soot_toolkits_scalar_SimpleLiveLocals$object *, struct _jc_soot_toolkits_graph_UnitGraph$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_object *_jc_soot_toolkits_scalar_SimpleLiveLocals$method$getLiveLocalsAfter$18404ef042e9c3a3(_jc_env *, struct _jc_soot_toolkits_scalar_SimpleLiveLocals$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_soot_toolkits_scalar_SimpleLiveLocals$method$getLiveLocalsBefore$9ac8223d771605d4(_jc_env *, struct _jc_soot_toolkits_scalar_SimpleLiveLocals$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_toolkits_scalar_SimpleLiveLocals$method_info$getLiveLocalsAfter$18404ef042e9c3a3;
extern _jc_method _jc_soot_toolkits_scalar_SimpleLiveLocals$method_info$getLiveLocalsBefore$9ac8223d771605d4;

// Virtual methods structure
struct _jc_soot_toolkits_scalar_SimpleLiveLocals$vmethods {
	struct _jc_object	*(*getLiveLocalsAfter$18404ef042e9c3a3)(_jc_env *, struct _jc_soot_toolkits_scalar_SimpleLiveLocals$object *, struct _jc_object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*getLiveLocalsBefore$9ac8223d771605d4)(_jc_env *, struct _jc_soot_toolkits_scalar_SimpleLiveLocals$object *, struct _jc_object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_toolkits_scalar_SimpleLiveLocals$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_toolkits_scalar_SimpleLiveLocals$vmethods	soot_toolkits_scalar_SimpleLiveLocals;
};

// Vtype
struct _jc_soot_toolkits_scalar_SimpleLiveLocals$vtype {
	_jc_type			type;
	_jc_soot_toolkits_scalar_SimpleLiveLocals$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_toolkits_scalar_SimpleLiveLocals$sub_refs {
	struct _jc_object	*unitToLocalsAfter;
	struct _jc_object	*unitToLocalsBefore;
};

// Reference instance fields (object)
struct _jc_soot_toolkits_scalar_SimpleLiveLocals$refs {
    _jc_soot_toolkits_scalar_SimpleLiveLocals$sub_refs	soot_toolkits_scalar_SimpleLiveLocals;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_toolkits_scalar_SimpleLiveLocals$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_toolkits_scalar_SimpleLiveLocals$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_toolkits_scalar_SimpleLiveLocals$sub_nonrefs	soot_toolkits_scalar_SimpleLiveLocals;
};

// Object instance structure
struct _jc_soot_toolkits_scalar_SimpleLiveLocals$object {
	_jc_soot_toolkits_scalar_SimpleLiveLocals$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_toolkits_scalar_SimpleLiveLocals$vtype	*vtype;
	_jc_soot_toolkits_scalar_SimpleLiveLocals$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_toolkits_scalar_SimpleLiveLocals$vtype _jc_soot_toolkits_scalar_SimpleLiveLocals$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_toolkits_scalar_SimpleLiveLocals, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_toolkits_scalar_SimpleLiveLocals$class_object;

#endif	/* _JC_soot_toolkits_scalar_SimpleLiveLocals_H_ */
